@@ -29,6 +29,11 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     this->setWindowModality(Qt::ApplicationModal);
     this->setMinimumSize(640, 520);
 
+    QSettings settings;
+    this->resize(settings.value("AccountDialog/accountWindowSize",
+                                QSize(760, 620)).toSize());
+
+
     this->pController = pumpController;
 
     connect(pController, SIGNAL(openingAuthorizeURL(QUrl)),
@@ -236,7 +241,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     this->setLayout(mainLayout);
 
 
-    QSettings settings;  // Load saved User ID
+    // Load saved User ID, and authorization status
     userIdLineEdit->setText(settings.value("userID").toString());
 
     this->showAuthorizationStatus(settings.value("isApplicationAuthorized",
@@ -417,7 +422,7 @@ void AccountDialog::saveDetails()
         this->saveButton->setDisabled(true);
     }
 
-    this->hide(); // close() would end program if main window was hidden
+    this->hide();
 }
 
 
@@ -437,5 +442,11 @@ void AccountDialog::hideEvent(QHideEvent *event)
 {
     this->setLockMode(this->pController->currentlyAuthorized());
 
+    QSettings settings;
+    if (settings.isWritable())
+    {
+        settings.setValue("AccountDialog/accountWindowSize", this->size());
+    }
+
     event->accept();
 }
