@@ -69,6 +69,9 @@ public:
     QString generateTooltip();
     QString generateSnippet(int charLimit);
 
+    void setFilterMatches(QVariantMap newFilterMatches);
+    QVariantMap getFilterMatches();
+
 
 signals:
 
@@ -100,6 +103,8 @@ private:
     QString sharedByName;
     QString sharedById;
     QString sharedByAvatar;
+
+    QVariantMap filterMatches;
 };
 
 #endif // ASACTIVITY_H
