@@ -106,6 +106,23 @@ QString ASPerson::getNameWithFallback()
     }
 }
 
+
+QString ASPerson::makeNameIdString(QString userName, QString userId)
+{
+    QString nameAndId = userName.trimmed();
+    if (nameAndId.isEmpty())
+    {
+        nameAndId = userId;
+    }
+    else
+    {
+        nameAndId.append(" (" + userId + ")");
+    }
+
+    return nameAndId;
+}
+
+
 QString ASPerson::getHometown()
 {
     return hometown;
@@ -133,7 +150,14 @@ QString ASPerson::getTooltipInfo()
         return QString(); // If there's no ID, there's no valid person data
     }
 
-    QString tooltipContents = "<b>" + this->name + "</b><br>";
+    // FIXME: make these fields safe for HTML
+
+    QString tooltipContents;
+    if (!this->name.trimmed().isEmpty())
+    {
+        tooltipContents.append("<b>" + this->name.trimmed() + "</b><br>");
+    }
+
     tooltipContents.append("<b><i>" + this->id + "</i></b>");
 
     if (!this->hometown.isEmpty() || !this->bio.isEmpty())
