@@ -53,7 +53,7 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
 
 
 
-    // Left side, all contacts, with filter
+    // Upper-left side, all contacts, with filter
     this->peopleWidget = new PeopleWidget(tr("&Add to Selected") + " >>",
                                           PeopleWidget::EmbeddedWidget,
                                           pumpController,
@@ -66,6 +66,7 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
 
 
     this->allGroupboxLayout = new QVBoxLayout();
+    allGroupboxLayout->setContentsMargins(0, 0, 0, 0);
     allGroupboxLayout->addWidget(peopleWidget);
 
     allContactsGroupbox = new QGroupBox(tr("All Contacts"),
@@ -73,7 +74,7 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     allContactsGroupbox->setLayout(allGroupboxLayout);
 
 
-    // Right side, selected contacts
+    // Upper-right side, selected contacts
     explanationLabel = new QLabel(tr("Select people from the list on the left.\n"
                                      "You can drag them with the mouse, click or "
                                      "double-click on them, or select them and "
@@ -97,6 +98,22 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
             selectedListWidget, SLOT(clear()));
 
 
+    selectedGroupboxLayout = new QVBoxLayout();
+    selectedGroupboxLayout->addWidget(explanationLabel);
+    selectedGroupboxLayout->addSpacing(8);
+    selectedGroupboxLayout->addWidget(selectedListWidget);
+    selectedGroupboxLayout->addWidget(clearSelectedListButton);
+
+    this->selectedListGroupbox = new QGroupBox(tr("Selected People"),
+                                               this);
+    selectedListGroupbox->setLayout(selectedGroupboxLayout);
+
+    this->upperLayout = new QHBoxLayout();
+    upperLayout->addWidget(allContactsGroupbox,  3);
+    upperLayout->addWidget(selectedListGroupbox, 4);
+
+
+    // Lower part
     doneButton = new QPushButton(QIcon::fromTheme("dialog-ok",
                                                   QIcon(":/images/button-save.png")),
                                  tr("&Done"),
@@ -117,21 +134,9 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     buttonsLayout->addWidget(cancelButton);
 
 
-    selectedGroupboxLayout = new QVBoxLayout();
-    selectedGroupboxLayout->addWidget(explanationLabel);
-    selectedGroupboxLayout->addSpacing(12);
-    selectedGroupboxLayout->addWidget(selectedListWidget);
-    selectedGroupboxLayout->addWidget(clearSelectedListButton);
-    selectedGroupboxLayout->addSpacing(8);
-    selectedGroupboxLayout->addLayout(buttonsLayout);
-
-    this->selectedListGroupbox = new QGroupBox(tr("Selected People"),
-                                               this);
-    selectedListGroupbox->setLayout(selectedGroupboxLayout);
-
-    this->mainLayout = new QHBoxLayout();
-    mainLayout->addWidget(allContactsGroupbox,  3);
-    mainLayout->addWidget(selectedListGroupbox, 4);
+    this->mainLayout = new QVBoxLayout();
+    mainLayout->addLayout(upperLayout);
+    mainLayout->addLayout(buttonsLayout);
     this->setLayout(mainLayout);
 
 
