@@ -77,8 +77,9 @@ protected:
 private:
     QString selectorType;
 
-    QHBoxLayout *mainLayout;
+    QVBoxLayout *mainLayout;
 
+    QHBoxLayout *upperLayout;
 
     QVBoxLayout *allGroupboxLayout;
     QGroupBox *allContactsGroupbox;
