@@ -279,10 +279,13 @@ void AvatarButton::followUser()
 
 void AvatarButton::unfollowUser()
 {
+    QString nameWithId = ASPerson::makeNameIdString(this->authorName,
+                                                    this->authorId);
+
     int confirmation = QMessageBox::question(this, tr("Stop following?"),
                                              tr("Are you sure you want to "
                                                 "stop following %1?")
-                                             .arg(this->authorId),
+                                             .arg(nameWithId),
                                              tr("&Yes, stop following"),
                                              tr("&No"), "", 1, 1);
 
