@@ -65,7 +65,7 @@ ColorPicker::ColorPicker(QString description,
         }
         else
         {
-            this->currentColor = QColor(Qt::gray);
+            this->currentColor = QColor(Qt::blue);
         }
     }
     this->setButtonColor(currentColor);
