@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -59,13 +59,14 @@ Comment::Comment(PumpController *pumpController,
     }
 
     this->commentIsDeleted = false;
+    this->commentHasImages = false;
 
 
     // Avatar pixmap
     avatarButton = new AvatarButton(commentObject->author(),
                                     this->pController,
                                     this->globalObj,
-                                    QSize(32,32),
+                                    this->globalObj->getCommentAvatarSize(),
                                     this);
 
 
@@ -83,7 +84,8 @@ Comment::Comment(PumpController *pumpController,
     }
 
 
-    fullNameLabel = new QLabel(commentObject->author()->getNameWithFallback());
+    fullNameLabel = new QLabel(commentObject->author()->getNameWithFallback(),
+                               this);
     fullNameLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
     fullNameLabel->setFont(metadataFont);
     fullNameLabel->setToolTip(commentAuthorId);
@@ -129,9 +131,8 @@ Comment::Comment(PumpController *pumpController,
             this, SLOT(quoteComment()));
 
 
-    editLabel = new QLabel("<a href=\"edit://\">"
-                           + tr("Edit")
-                           + "</a>", this);
+    editLabel = new QLabel("<a href=\"edit://\">" + tr("Edit") + "</a>",
+                           this);
     editLabel->setContextMenuPolicy(Qt::NoContextMenu);
     editLabel->setAlignment(Qt::AlignTop | Qt::AlignRight);
     editLabel->setFont(metadataFont);
@@ -142,8 +143,8 @@ Comment::Comment(PumpController *pumpController,
 
 
     deleteLabel = new QLabel("<a href=\"delete://\">"
-                             + tr("Delete")
-                             + "</a>", this);
+                             + tr("Delete") + "</a>",
+                             this);
     deleteLabel->setContextMenuPolicy(Qt::NoContextMenu);
     deleteLabel->setAlignment(Qt::AlignTop | Qt::AlignRight);
     deleteLabel->setFont(metadataFont);
@@ -366,6 +367,11 @@ void Comment::setCommentContents()
     QStringList commentImageList = MiscHelpers::htmlWithReplacedImages(commentOriginalText,
                                                                        imageWidth);
 
+    if (commentImageList.size() > 1) // First is the HTML itself
+    {
+        this->commentHasImages = true;
+    }
+
     QString commentContents = commentImageList.takeAt(0); // Comment's HTML with images replaced
     this->contentLabel->setText(commentContents);
 }
@@ -375,8 +381,15 @@ void Comment::onResize()
 {
     contentLabel->ensurePolished();
     int height = contentLabel->heightForWidth(contentLabel->width());
+
     this->contentLabel->setMinimumHeight(height);
-    this->contentLabel->setMaximumHeight(height);
+
+    // Forcing maximum height cuts images and is not really needed when images
+    // are present, thanks to fixes elsewhere, so enforce it only then
+    if (!this->commentHasImages)
+    {
+        this->contentLabel->setMaximumHeight(height);
+    }
 }
 
 
