@@ -22,12 +22,14 @@
 
 CommenterBlock::CommenterBlock(PumpController *pumpController,
                                GlobalObject *globalObject,
+                               QString parentId,
                                QString parentAuthorId,
                                bool parentStandalone,
                                QWidget *parent) : QWidget(parent)
 {
     this->pController = pumpController;
     this->globalObj = globalObject;
+    this->parentPostId = parentId;
     this->parentPostAuthorId = parentAuthorId;
     this->parentPostStandalone = parentStandalone;
 
@@ -66,9 +68,7 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     commentsWidget->setLayout(commentsLayout);
 
     this->commentsScrollArea = new QScrollArea(this);
-    //commentsScrollArea->setFrameStyle(QFrame::NoFrame);
     commentsScrollArea->setContentsMargins(0, 0, 0, 0);
-    //commentsScrollArea->setSizePolicy(sizePolicy);
     commentsScrollArea->setSizePolicy(QSizePolicy::Minimum,
                                       QSizePolicy::Preferred);
     commentsScrollArea->setWidget(commentsWidget);
@@ -185,6 +185,11 @@ void CommenterBlock::clearComments()
 
 void CommenterBlock::setComments(QVariantList commentsList, int commentCount)
 {
+    this->reloadErrorString.clear(); // No error to show!
+    disconnect(pController, SIGNAL(commentsNotReceived(QString)),
+               this, SLOT(onCommentsNotReceived(QString)));
+
+
     if (commentCount > 0)
     {
         // If some comments are actually included, clear first
@@ -222,6 +227,11 @@ void CommenterBlock::setComments(QVariantList commentsList, int commentCount)
         // Trying immediately first avoids a flicker-like effect sometimes
         scrollToBottomTimer->start(500);
     }
+    else
+    {
+        // For cases where 0 comments were received, after specifically reloading
+        this->updateShowAllLink();
+    }
 }
 
 
@@ -335,26 +345,11 @@ void CommenterBlock::setCommentDeletedFromObject(ASObject *object)
 }
 
 
-void CommenterBlock::updateFuzzyTimestamps()
-{
-    foreach (Comment *comment, this->commentsInBlock)
-    {
-        comment->setFuzzyTimestamps();
-    }
-}
-
-void CommenterBlock::updateAvatarFollowStates()
-{
-    foreach (Comment *comment, this->commentsInBlock)
-    {
-        comment->syncAvatarFollowState();
-    }
-}
-
 
 void CommenterBlock::updateShowAllLink()
 {
     QString showAllString;
+
     if (allCommentsShown)
     {
         showAllString = this->reloadCommentsString;
@@ -374,11 +369,13 @@ void CommenterBlock::updateShowAllLink()
         }
     }
 
+
     // Small trick to avoid a bug where the link stops having appropriate mouse pointer
     this->showAllCommentsLinkLabel->clear();
     this->showAllCommentsLinkLabel->hide();
 
-    this->showAllCommentsLinkLabel->setText("<a href=\"showall://\">"
+    this->showAllCommentsLinkLabel->setText(this->reloadErrorString
+                                            + " <a href=\"showall://\">"
                                             + showAllString
                                             + "</a>");
     this->showAllCommentsLinkLabel->show();
@@ -398,6 +395,23 @@ void CommenterBlock::disableShowAllLink()
 
 
 
+void CommenterBlock::updateFuzzyTimestamps()
+{
+    foreach (Comment *comment, this->commentsInBlock)
+    {
+        comment->setFuzzyTimestamps();
+    }
+}
+
+void CommenterBlock::updateAvatarFollowStates()
+{
+    foreach (Comment *comment, this->commentsInBlock)
+    {
+        comment->syncAvatarFollowState();
+    }
+}
+
+
 void CommenterBlock::adjustCommentsWidth()
 {
     //commentsWidget->setMaximumWidth(commentsScrollArea->viewport()->width() - 2);
@@ -531,7 +545,8 @@ void CommenterBlock::editComment(QString id, QString content)
     {
         QMessageBox::warning(this, tr("Error: Already composing"),
                              tr("You can't edit a comment at this time, "
-                                "because another comment is already being composed."));
+                                "because another comment is already "
+                                "being composed."));
         return;
     }
 
@@ -550,7 +565,14 @@ void CommenterBlock::editComment(QString id, QString content)
 
 void CommenterBlock::requestAllComments()
 {
-    emit allCommentsRequested(); // FIXME 1.3.x: could connect() to this signal directly
+    // Show feedback in place, regardless of statusbar message
+    this->showAllCommentsLinkLabel->setText("<b></b>&sim; &nbsp;" // ~
+                                            + tr("Loading comments..."));
+
+    connect(pController, SIGNAL(commentsNotReceived(QString)),
+            this, SLOT(onCommentsNotReceived(QString)));
+
+    emit allCommentsRequested();
 }
 
 
@@ -560,8 +582,15 @@ void CommenterBlock::requestAllComments()
  * which means comment posted (or updated) successfully.
  *
  */
-void CommenterBlock::onPostingCommentOk()
+void CommenterBlock::onPostingCommentOk(QString postId)
 {
+    if (postId != this->parentPostId)
+    {
+        // Not related to this post...
+        return;
+    }
+
+
     // Clear info message
     this->statusInfoLabel->clear();
 
@@ -579,10 +608,10 @@ void CommenterBlock::onPostingCommentOk()
     setMinimumMode();
 
 
-    disconnect(pController, SIGNAL(commentPosted()),
-               this, SLOT(onPostingCommentOk()));
-    disconnect(pController, SIGNAL(commentPostingFailed()),
-               this, SLOT(onPostingCommentFailed()));
+    disconnect(pController, SIGNAL(commentPosted(QString)),
+               this, SLOT(onPostingCommentOk(QString)));
+    disconnect(pController, SIGNAL(commentPostingFailed(QString)),
+               this, SLOT(onPostingCommentFailed(QString)));
 
 
     this->getAllCommentsTimer->start(3000); // Request comments after a delay
@@ -593,8 +622,15 @@ void CommenterBlock::onPostingCommentOk()
  * Executed when commentPostingFailed() signal is received from PumpController
  *
  */
-void CommenterBlock::onPostingCommentFailed()
+void CommenterBlock::onPostingCommentFailed(QString postId)
 {
+    if (postId != this->parentPostId)
+    {
+        // Not related to this post...
+        return;
+    }
+
+
     qDebug() << "Posting the comment failed, re-enabling Commenter";
 
     // Alert about the error
@@ -604,10 +640,22 @@ void CommenterBlock::onPostingCommentFailed()
     this->setEnabled(true);
     this->commentComposer->setFocus();
 
-    disconnect(pController, SIGNAL(commentPostingFailed()),
-               this, SLOT(onPostingCommentFailed()));
-    disconnect(pController, SIGNAL(commentPosted()),
-               this, SLOT(onPostingCommentOk()));
+    disconnect(pController, SIGNAL(commentPostingFailed(QString)),
+               this, SLOT(onPostingCommentFailed(QString)));
+    disconnect(pController, SIGNAL(commentPosted(QString)),
+               this, SLOT(onPostingCommentOk(QString)));
+}
+
+
+void CommenterBlock::onCommentsNotReceived(QString id)
+{
+    if (id == this->parentPostId)
+    {
+        this->reloadErrorString = tr("An error occurred")
+                                  + " - ";
+
+        this->updateShowAllLink();
+    }
 }
 
 
@@ -621,10 +669,10 @@ void CommenterBlock::sendComment()
     // If there's some text in the comment, send it
     if (commentComposer->textCursor().document()->characterCount() > 1)
     {
-        connect(pController, SIGNAL(commentPosted()),
-                this, SLOT(onPostingCommentOk()));
-        connect(pController, SIGNAL(commentPostingFailed()),
-                this, SLOT(onPostingCommentFailed()));
+        connect(pController, SIGNAL(commentPosted(QString)),
+                this, SLOT(onPostingCommentOk(QString)));
+        connect(pController, SIGNAL(commentPostingFailed(QString)),
+                this, SLOT(onPostingCommentFailed(QString)));
 
         if (!editingMode)
         {
