@@ -44,6 +44,7 @@ class CommenterBlock : public QWidget
 public:
     explicit CommenterBlock(PumpController *pumpController,
                             GlobalObject *globalObject,
+                            QString parentId,
                             QString parentAuthorId,
                             bool parentStandalone,
                             QWidget *parent = 0);
@@ -55,11 +56,12 @@ public:
     void updateCommentFromObject(ASObject *object);
     void setCommentDeletedFromObject(ASObject *object);
 
-    void updateFuzzyTimestamps();
-    void updateAvatarFollowStates();
     void updateShowAllLink();
     void disableShowAllLink();
 
+    void updateFuzzyTimestamps();
+    void updateAvatarFollowStates();
+
     void adjustCommentsWidth();
     void adjustCommentsHeight();
     void adjustCommentArea();
@@ -87,8 +89,9 @@ public slots:
     void editComment(QString id, QString content);
 
     void requestAllComments();
-    void onPostingCommentOk();
-    void onPostingCommentFailed();
+    void onPostingCommentOk(QString postId);
+    void onPostingCommentFailed(QString postId);
+    void onCommentsNotReceived(QString id);
 
     void sendComment();
 
@@ -107,8 +110,10 @@ private:
     QVBoxLayout *commentsLayout;
     QTimer *scrollToBottomTimer;
 
+    QString parentPostId;
 
     QString reloadCommentsString;
+    QString reloadErrorString;
     QLabel *showAllCommentsLinkLabel;
     QTimer *getAllCommentsTimer; // To get all comments after a delay
 
