@@ -506,7 +506,8 @@ void Composer::insertFromMimeData(const QMimeData *source)
     {
         cursor.select(QTextCursor::WordUnderCursor);
 
-        QString currentWord = cursor.selection().toPlainText();
+        QString currentWord = cursor.selection().toPlainText()
+                                                .trimmed(); // Strip possible zero-widths
 
         qDebug() << "WORD:" << currentWord;
 
