@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -37,6 +37,9 @@
 #include <QStandardItemModel>
 #include <QTableView>
 #include <QHeaderView>
+#include <QTextDocument>
+#include <QTextDocumentFragment>
+#include <QTextCursor>
 
 #include <QDebug>
 
