@@ -607,6 +607,19 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
 
     notificationsStatusLabel = new QLabel(this);
 
+    notificationDurationSpinbox = new QSpinBox(this);
+    notificationDurationSpinbox->setRange(1, 60);
+    notificationDurationSpinbox->setSuffix(" " + tr("seconds",
+                                                    "Next to a duration, in seconds"));
+    notificationDurationSpinbox->setValue(settings->value("notificationDuration",
+                                                          4).toInt()); // 4s default
+
+    notificationPersistentCheckbox = new QCheckBox(this);
+    connect(notificationPersistentCheckbox, SIGNAL(toggled(bool)),
+            notificationDurationSpinbox, SLOT(setDisabled(bool)));
+    notificationPersistentCheckbox->setChecked(settings->value("notificationPersistent",
+                                                               false).toBool());
+
     notifyNewTLCheckbox = new QCheckBox(this);
     notifyNewTLCheckbox->setChecked(settings->value("notifyNewTL",
                                                     false).toBool());
@@ -634,8 +647,14 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
                                       notificationStyleCombobox);
     notificationOptionsLayout->addRow("", // Empty label on left to align with right column
                                       notificationsStatusLabel);
-    notificationOptionsLayout->addRow(new QLabel("<br>" // TMP/FIXME: put these options inside a GroupBox?
-                                                 "<b>"
+    notificationOptionsLayout->addRow(tr("Duration"),
+                                      notificationDurationSpinbox);
+    notificationOptionsLayout->addRow(tr("Persistent Notifications"),
+                                      notificationPersistentCheckbox);
+
+
+    notificationOptionsLayout->addRow(new QLabel("<br>" // TMP/FIXME: put these options
+                                                 "<b>"  //            inside a GroupBox?
                                                  + tr("Notify when receiving:")
                                                  + "</b>"
                                                    "<br>",
@@ -732,7 +751,14 @@ void ConfigDialog::syncNotifierOptions()
 {
     this->toggleNotificationDetails(notificationStyleCombobox->currentIndex());
 
+    int notificationDuration = notificationDurationSpinbox->value();
+    if (notificationPersistentCheckbox->isChecked())
+    {
+        notificationDuration = 0;
+    }
+
     this->fdNotifier->setNotificationOptions(notificationStyleCombobox->currentIndex(),
+                                             notificationDuration,
                                              notifyNewTLCheckbox->isChecked(),
                                              notifyHLTLCheckbox->isChecked(),
                                              notifyNewMWCheckbox->isChecked(),
@@ -924,6 +950,10 @@ void ConfigDialog::saveConfiguration()
     // Notifications
     settings.setValue("showNotifications",
                       this->notificationStyleCombobox->currentIndex());
+    settings.setValue("notificationDuration",
+                      this->notificationDurationSpinbox->value());
+    settings.setValue("notificationPersistent",
+                      this->notificationPersistentCheckbox->isChecked());
     settings.setValue("notifyNewTL",  this->notifyNewTLCheckbox->isChecked());
     settings.setValue("notifyHLTL",   this->notifyHLTLCheckbox->isChecked());
     settings.setValue("notifyNewMW",  this->notifyNewMWCheckbox->isChecked());
@@ -937,7 +967,8 @@ void ConfigDialog::saveConfiguration()
     settings.setValue("systrayIconType", this->systrayIconTypeCombobox->currentIndex());
     settings.setValue("systrayCustomIconFN", this->systrayCustomIconFN);
     settings.setValue("systrayHideInTray", this->systrayHideCheckbox->isChecked());
-    this->globalObj->syncTrayOptions(this->systrayHideCheckbox->isChecked()); // FIXME, some still empty
+    this->globalObj->syncTrayOptions(this->systrayHideCheckbox->isChecked()); // FIXME: some
+                                                                              // still empty
 
 
     settings.endGroup();
