@@ -202,6 +202,8 @@ private:
     QFormLayout *notificationOptionsLayout;
 
     QComboBox *notificationStyleCombobox;
+    QSpinBox *notificationDurationSpinbox;
+    QCheckBox *notificationPersistentCheckbox;
     QLabel *notificationsStatusLabel;
     QCheckBox *notifyNewTLCheckbox;
     QCheckBox *notifyHLTLCheckbox;
