@@ -88,7 +88,7 @@ private:
     QAction *openProfileAction;
     QAction *sendMessageAction;
     QAction *browsePostsAction;
-    QMenu *addToListMenu;
+    //QMenu *addToListMenu;
 
 
     PumpController *pController;
