@@ -46,6 +46,10 @@ ContactList::ContactList(PumpController *pumpController,
                           .pixmap(iconSize, iconSize));
 
 
+    this->matchesLabel = new QLabel(this);
+    matchesLabel->hide();
+
+
     this->removeFilterButton = new QPushButton(QIcon::fromTheme("view-list-icons"),
                                                tr("F&ull List"),
                                                this);
@@ -65,6 +69,7 @@ ContactList::ContactList(PumpController *pumpController,
     this->filterLayout = new QHBoxLayout();
     filterLayout->addWidget(filterIcon, 0, Qt::AlignVCenter);
     filterLayout->addWidget(filterLineEdit);
+    filterLayout->addWidget(matchesLabel);
     filterLayout->addWidget(removeFilterButton);
 
     this->contactsLayout = new QVBoxLayout();
@@ -254,11 +259,13 @@ void ContactList::filterList(QString filterText)
 
     if (!filterText.isEmpty())
     {
+        int matchCount = 0;
         foreach (ContactCard *card, contactsInList)
         {
             if (card->getNameAndIdString().contains(filterText, Qt::CaseInsensitive))
             {
                 card->show();
+                ++matchCount;
             }
             else
             {
@@ -266,6 +273,9 @@ void ContactList::filterList(QString filterText)
             }
         }
 
+        matchesLabel->setText(QString("(%1)")
+                              .arg(QLocale::system().toString(matchCount)));
+        matchesLabel->show();
         removeFilterButton->setEnabled(true);
     }
     else // If no filter at all, more optimized version showing all
@@ -275,6 +285,8 @@ void ContactList::filterList(QString filterText)
             card->show();
         }
 
+        matchesLabel->setText("");
+        matchesLabel->hide();
         removeFilterButton->setDisabled(true);
     }
 }
