@@ -65,6 +65,9 @@ ContactManager::ContactManager(PumpController *pumpController,
     addressLineEdit->setPlaceholderText(webfingerHelpMessage);
     addressLineEdit->setToolTip("<b></b>"
                                 + webfingerHelpMessage);  // HTML tags to get wordwrap
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    addressLineEdit->setClearButtonEnabled(true);
+#endif
     connect(addressLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(toggleFollowButton(QString)));
     connect(addressLineEdit, SIGNAL(returnPressed()),
