@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -60,8 +60,12 @@ public:
 
     void exportContactsToFile(QString listType);
 
+    void enableManualFollowWidgets();
+
+
 signals:
 
+
 public slots:
     void setContactListsContents(QString listType,
                                  QVariantList contactList,
@@ -79,7 +83,11 @@ public slots:
     void refreshPersonLists();
 
     void toggleFollowButton(QString currentAddress);
-    void followContact();
+
+    void validateContactId();
+    void followContact(QString userId, int httpCode,
+                       bool requestTimedOut, QString serverVersion);
+    void onCantFollowNow(QString userId);
 
 
 protected:
@@ -110,6 +118,9 @@ private:
     QPushButton *optionsButton;
     QMenu *optionsMenu;
 
+    bool followingManually;
+    QString followingAddress;
+
     PumpController *pController;
     GlobalObject *globalObj;
 };
