@@ -53,6 +53,7 @@ signals:
 
 public slots:
     void downloadAttachment();
+    void openAttachment();
     void cancelDownload();
     void completeDownload(QString url);
     void onDownloadFailed(QString url);
@@ -64,6 +65,7 @@ public slots:
 private:
     QHBoxLayout *mainLayout;
     QLabel *infoLabel;
+    QPushButton *openButton;
     QProgressBar *progressBar;
     QPushButton *downloadButton;
     QPushButton *cancelButton;
