@@ -76,7 +76,8 @@ void FilterChecker::setFilters(QVariantList newFiltersList)
         }
     }
 
-    qDebug() << "FilterChecker() filters updated, with" << newFiltersList.length() << "filters";
+    qDebug() << "FilterChecker() filters updated, with"
+             << newFiltersList.length() << "filters";
 }
 
 
@@ -87,7 +88,13 @@ void FilterChecker::setFilters(QVariantList newFiltersList)
  */
 int FilterChecker::validateActivity(ASActivity *activity)
 {
-    int filtered = NoFiltering;  // Innocent until proven guilty!
+    QVariantMap filterMatches;
+
+    int filterAction = NoFiltering;  // Innocent until proven guilty!
+    QStringList matchingContent;
+    QStringList matchingAuthor;
+    QStringList matchingGenerator;
+    QStringList matchingDescription;
 
 
     QString postTitle = activity->object()->getTitle();
@@ -97,8 +104,11 @@ int FilterChecker::validateActivity(ASActivity *activity)
         if (postContents.contains(contents.first(), Qt::CaseInsensitive)
          || postTitle.contains(contents.first(), Qt::CaseInsensitive))
         {
-            qDebug() << "Filtering item because of Post Content:" << contents.first();
-            filtered = contents.last().toInt();
+            qDebug() << "Filtering item because of Post Content:"
+                     << contents.first();
+
+            filterAction = contents.last().toInt();
+            matchingContent.append(contents.first());
         }
     }
 
@@ -109,8 +119,11 @@ int FilterChecker::validateActivity(ASActivity *activity)
         if (activityAuthorId.contains(authorId.first(), Qt::CaseInsensitive)
          || objectAuthorId.contains(authorId.first(), Qt::CaseInsensitive))
         {
-            qDebug() << "Filtering item because of Author ID:" << authorId.first();
-            filtered = authorId.last().toInt();
+            qDebug() << "Filtering item because of Author ID:"
+                     << authorId.first();
+
+            filterAction = authorId.last().toInt();
+            matchingAuthor.append(authorId.first());
         }
     }
 
@@ -120,8 +133,11 @@ int FilterChecker::validateActivity(ASActivity *activity)
     {
         if (activityGenerator.contains(generator.first(), Qt::CaseInsensitive))
         {
-            qDebug() << "Filtering item because of Application (generator):" << generator.first();
-            filtered = generator.last().toInt();
+            qDebug() << "Filtering item because of Application (generator):"
+                     << generator.first();
+
+            filterAction = generator.last().toInt();
+            matchingGenerator.append(generator.first());
         }
     }
 
@@ -131,11 +147,23 @@ int FilterChecker::validateActivity(ASActivity *activity)
     {
         if (activityDescription.contains(description.first(), Qt::CaseInsensitive))
         {
-            qDebug() << "Filtering item because of Activity Description:" << description.first();
-            filtered = description.last().toInt();
+            qDebug() << "Filtering item because of Activity Description:"
+                     << description.first();
+
+            filterAction = description.last().toInt();
+            matchingDescription.append(description.first());
         }
     }
 
 
-    return filtered;
+    filterMatches.insert("filterAction",        filterAction);
+    filterMatches.insert("matchingContent",     matchingContent);
+    filterMatches.insert("matchingAuthor",      matchingAuthor);
+    filterMatches.insert("matchingGenerator",   matchingGenerator);
+    filterMatches.insert("matchingDescription", matchingDescription);
+
+    activity->setFilterMatches(filterMatches);
+
+
+    return filterAction;
 }
