@@ -88,6 +88,9 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
 
     filterWordsLineEdit = new QLineEdit(this);
     filterWordsLineEdit->setPlaceholderText(tr("Keywords..."));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    filterWordsLineEdit->setClearButtonEnabled(true);
+#endif
 
     addFilterButton = new QPushButton(QIcon::fromTheme("list-add",
                                                        QIcon(":/images/list-add.png")),
