@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ FontPicker::FontPicker(QString description,
 
     this->button = new QPushButton(QIcon::fromTheme("list-add-font",
                                                     QIcon(":/images/list-add.png")),
-                                   tr("Change"),
+                                   tr("Change..."),
                                    this);
     connect(button, SIGNAL(clicked()),
             this, SLOT(selectFont()));
