@@ -54,13 +54,13 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 
     //////////////////////////////////////////////////////////////////// COLORS
     this->colorsList.clear();                           // Defaults:
-    colorsList << settings.value("color1", "#DD2030").toString() // Red
-               << settings.value("color2", "#60AADD").toString() // Blue
+    colorsList << settings.value("color1", "#CC2030").toString() // Red
+               << settings.value("color2", "#5599CC").toString() // Blue
                << settings.value("color3", "#DDCC10").toString() // Yellow
                << settings.value("color4", "#10BB10").toString() // Green
-               << settings.value("color5").toString()
+               << settings.value("color5", "#AA77EE").toString() // Purple
                << settings.value("color6").toString();
-    // No need to call this->syncColorSettings() now...
+    // No need to call this->syncColorSettings() here...
 
 
     ///////////////////////////////////////////////////////////////// TIMELINES
@@ -124,6 +124,9 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
     // Timeline height used to calculate maximum optimal height for post contents
     this->timelineHeight = 400; // Some initial value
 
+
+    this->programClosing = false;
+
     qDebug() << "GlobalObject created";
 }
 
@@ -494,6 +497,8 @@ void GlobalObject::addToNickCompletionModel(QString id, QString name,
 
 void GlobalObject::removeFromNickCompletionModel(QString id)
 {
+    qDebug() << "GlobalObject::removeFromNickCompletionModel()" << id;
+
     QList<QStandardItem *> allNicks;
     allNicks = nickCompletionModel->findItems("", Qt::MatchContains);
 
@@ -503,7 +508,16 @@ void GlobalObject::removeFromNickCompletionModel(QString id)
 
         if (item->data(Qt::UserRole + 1).toString() == id)
         {
-            this->nickCompletionModel->removeRow(item->row());
+            int rowNum = item->row();
+            /*
+             * FIXME: Ensure deleting the item is not needed.
+             * Deleting it before removeRow doesn't seem to do any harm.
+             * removeRow seems to delete it anyway; trying to delete it
+             * afterwards results in segfault.
+             *
+             * delete item;
+             */
+            this->nickCompletionModel->removeRow(rowNum);
         }
     }
 }
@@ -586,3 +600,16 @@ QSize GlobalObject::getAvatarSizeForIndex(int index)
 
     return QSize(pixelSize, pixelSize);
 }
+
+
+
+void GlobalObject::notifyProgramShutdown()
+{
+    this->programClosing = true;
+    emit programShuttingDown();
+}
+
+bool GlobalObject::isProgramShuttingDown()
+{
+    return this->programClosing;
+}
