@@ -148,6 +148,9 @@ public:
 
     QSize getAvatarSizeForIndex(int index);
 
+    void notifyProgramShutdown();
+    bool isProgramShuttingDown();
+
 
 signals:
     void messagingModeRequested(QString id, QString name, QString url);
@@ -163,6 +166,7 @@ signals:
     void messageForStatusBar(QString message);
     void messageForLog(QString message, QString url);
 
+    void programShuttingDown();
 
 public slots:
 
@@ -234,6 +238,8 @@ private:
     // Other stuff
     QStandardItemModel *nickCompletionModel;
     int timelineHeight;
+
+    bool programClosing;
 };
 
 #endif // GLOBALOBJECT_H
