@@ -31,30 +31,34 @@ GroupsManager::GroupsManager(PumpController *pumpController,
     this->setWindowModality(Qt::ApplicationModal);
     this->setMinimumSize(400, 400);
 
-    this->newGroupNameLineEdit = new QLineEdit();
+    this->newGroupNameLineEdit = new QLineEdit(this);
     newGroupNameLineEdit->setPlaceholderText("Name for the new group");
 
-    this->newGroupSummaryLineEdit = new QLineEdit();
+    this->newGroupSummaryLineEdit = new QLineEdit(this);
     newGroupSummaryLineEdit->setPlaceholderText("Summary");
 
-    this->newGroupDescLineEdit = new QLineEdit();
+    this->newGroupDescLineEdit = new QLineEdit(this);
     newGroupDescLineEdit->setPlaceholderText("Longer description of the group");
 
     this->createGroupButton = new QPushButton(QIcon::fromTheme("user-group-new"),
-                                              "&CREATE GROUP");
+                                              "&CREATE GROUP",
+                                              this);
     connect(createGroupButton, SIGNAL(clicked()),
             this, SLOT(createGroup()));
 
-    this->joinLeaveGroupLineEdit = new QLineEdit();
-    joinLeaveGroupLineEdit->setPlaceholderText("ID of the group you wish to join or leave");
+    this->joinLeaveGroupLineEdit = new QLineEdit(this);
+    joinLeaveGroupLineEdit->setPlaceholderText("ID of the group you wish to "
+                                               "join or leave");
 
     this->joinGroupButton = new QPushButton(QIcon::fromTheme("list-add-user"),
-                                            "&JOIN!");
+                                            "&JOIN!",
+                                            this);
     connect(joinGroupButton, SIGNAL(clicked()),
             this, SLOT(joinGroup()));
 
     this->leaveGroupButton = new QPushButton(QIcon::fromTheme("list-remove-user"),
-                                             "&LEAVE");
+                                             "&LEAVE",
+                                             this);
     connect(leaveGroupButton, SIGNAL(clicked()),
             this, SLOT(leaveGroup()));
 
