@@ -224,7 +224,7 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append(tr("You can find a list with some Pump.io users "
                        "and other information here:")
                     + "<br>"
-                      "<a href=\"https://github.com/e14n/pump.io/wiki/Users-by-language\">"
+                      "<a href=\"https://github.com/pump-io/pump.io/wiki/Users-by-language\">"
                     + tr("Users by language")
                     + "</a> - <a href=\"https://pumpit.info/pumpio/followers\">"
                     + tr("Followers of Pump.io Community account")
