@@ -72,6 +72,9 @@ public slots:
     void zoomIn();
     void zoomOut();
 
+    void rotateLeft();
+    void rotateRight();
+
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
@@ -94,11 +97,17 @@ private:
     QPushButton *fullButton;
     QPushButton *zoomInButton;
     QPushButton *zoomOutButton;
+
+    QPushButton *rotateLeftButton;
+    QPushButton *rotateRightButton;
+
     QLabel *infoLabel;
     QPushButton *closeButton;
 
     QMenu *contextMenu;
     QAction *saveAction;
+    QAction *rotateLeftAction;
+    QAction *rotateRightAction;
     QAction *closeAction;
 
     QString imageUrl;
