@@ -78,6 +78,9 @@ ListsManager::ListsManager(PumpController *pumpController,
 
     this->newListNameLineEdit = new QLineEdit(this);
     newListNameLineEdit->setPlaceholderText(tr("Type a name for the new list..."));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    newListNameLineEdit->setClearButtonEnabled(true);
+#endif
     connect(newListNameLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(enableDisableCreateButton(QString)));
     connect(newListNameLineEdit, SIGNAL(returnPressed()),
