@@ -233,7 +233,6 @@ void MinorFeed::removeOldItems(int minimumToKeep)
     }
 
     int itemCounter = 0;
-    int deletedCounter = 0; // tmp, TESTS (EXTRALOGGING)
     foreach (MinorFeedItem *feedItem, itemsInFeed)
     {
         if (itemCounter >= maxItems)
@@ -243,7 +242,6 @@ void MinorFeed::removeOldItems(int minimumToKeep)
                 this->itemsLayout->removeWidget(feedItem);
                 this->itemsInFeed.removeOne(feedItem);
                 delete feedItem;
-                ++deletedCounter; // tmp, TESTS (EXTRALOGGING)
             }
         }
 
@@ -256,17 +254,6 @@ void MinorFeed::removeOldItems(int minimumToKeep)
 
     this->nextLink = this->pController->getFeedApiUrl(this->feedType)
                    + "?before=" + lastItemId;
-
-#ifdef EXTRALOGGING
-    // tmp, TESTS - debugging via log
-    this->globalObj->logMessage(QString(">>> %1 ITEMS IN '%2' AFTER CLEANUP; "
-                                        "%3 CAME, %4 REMOVED - Next: %5")
-                                .arg(itemsInFeed.count())
-                                .arg(PumpController::getFeedNameAndPath(this->feedType).first())
-                                .arg(minimumToKeep)
-                                .arg(deletedCounter)
-                                .arg(this->nextLink));
-#endif
 }
 
 
@@ -336,7 +323,7 @@ void MinorFeed::syncActivityWithTimelines(ASActivity *activity)
     if (activity->getVerb() == "favorite"
      || activity->getVerb() == "like")
     {
-        // FIXME: handle liking of comments (1.3.5)
+        // FIXME: handle liking of comments (1.3.6)
 
         if (ASObject::canDisplayObject(activity->object()->getType()))
         {
@@ -352,7 +339,7 @@ void MinorFeed::syncActivityWithTimelines(ASActivity *activity)
     if (activity->getVerb() == "unfavorite"
      || activity->getVerb() == "unlike")
     {
-        // FIXME: handle unliking of comments (1.3.5)
+        // FIXME: handle unliking of comments (1.3.6)
 
         if (ASObject::canDisplayObject(activity->object()->getType()))
         {
@@ -511,7 +498,7 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
                                               pController->currentUserId(),
                                               this);
 
-        int filtered = fChecker->validateActivity(activity);
+        int filtered = this->fChecker->validateActivity(activity);
 
         // If there is no reason to filter out the item, add it to the feed
         if (filtered != FilterChecker::FilterOut)
