@@ -108,12 +108,12 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     activityDescriptionLabel = new QLabel(this); // To be filled later
     QFont descriptionFont;
     descriptionFont.fromString(globalObj->getMinorFeedFont());
+    activityDescriptionLabel->setFont(descriptionFont);
     activityDescriptionLabel->setWordWrap(true);
     activityDescriptionLabel->setOpenExternalLinks(true);
     activityDescriptionLabel->setAlignment(Qt::AlignTop);
     activityDescriptionLabel->setSizePolicy(QSizePolicy::Ignored,
                                             QSizePolicy::MinimumExpanding);
-    activityDescriptionLabel->setFont(descriptionFont);
     connect(activityDescriptionLabel, SIGNAL(linkHovered(QString)),
             this, SLOT(showUrlInfo(QString)));
 
@@ -212,7 +212,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
             if (this->globalObj->getMinorFeedSnippetsType() > 0  // Always or any highlighted
              || authorId != pController->currentUserId())        // or highlighted but not ours (0)
             {
-                // FIXME 1.3.5: fix this spaghetti mess!!
+                // FIXME 1.3.6: fix this spaghetti mess!!
                 // TODO: option to not show when the object of the activity is ours
                 // i.e. "JohnDoe liked a note", our note
 
@@ -294,18 +294,36 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     }
 
 
-    mainLayout = new QHBoxLayout();
-    mainLayout->setContentsMargins(2, 1, 2, 4);
+
+    topLayout = new QHBoxLayout();
+    topLayout->setContentsMargins(0, 0, 0, 0);
     if (authorId == pController->currentUserId())
     {
-        mainLayout->addLayout(rightLayout, 20);
-        mainLayout->addLayout(leftLayout,  1);
+        topLayout->addLayout(rightLayout, 20);
+        topLayout->addLayout(leftLayout,  1);
     }
     else // Normal item, not ours
     {
-        mainLayout->addLayout(leftLayout,  1);
-        mainLayout->addLayout(rightLayout, 20);
+        topLayout->addLayout(leftLayout,  1);
+        topLayout->addLayout(rightLayout, 20);
     }
+
+
+    mainLayout = new QVBoxLayout();
+    mainLayout->setContentsMargins(2, 1, 2, 4);
+    mainLayout->addLayout(topLayout);
+
+    if (highlightedByFilter) // Show which filtering rules caused this item to be highlighted
+    {
+        QVariantMap filterMatches = activity->getFilterMatches();
+        if (filterMatches.value("filterAction").toInt() == FilterChecker::Highlight)
+        {
+            this->filterMatchesWidget = new FilterMatchesWidget(filterMatches, this);
+            mainLayout->addWidget(filterMatchesWidget);
+            // FIXME -- TODO: make this widget optional
+        }
+    }
+
     this->setLayout(mainLayout);
 
     qDebug() << "MinorFeedItem created";
@@ -439,12 +457,11 @@ void MinorFeedItem::openOriginalPost()
                                     true,  // Post is standalone
                                     pController,
                                     globalObj,
-                                    this->parentWidget()); // Pass parent widget (MinorFeed) instead
-                                                           // of 'this', so it won't be killed by reloads
+                                    nullptr); // Make it an independent window
     referencedPost->show();
     connect(pController, SIGNAL(commentsReceived(QVariantList,QString)),
             referencedPost, SLOT(setAllComments(QVariantList,QString)));
-    referencedPost->getAllComments();
+    referencedPost->requestCommenterComments();
 }
 
 
