@@ -37,6 +37,9 @@
 #include "asactivity.h"
 #include "post.h"
 #include "avatarbutton.h"
+#include "filterchecker.h"
+#include "filtermatcheswidget.h"
+
 
 
 class MinorFeedItem : public QFrame
@@ -78,7 +81,8 @@ private:
     PumpController *pController;
     GlobalObject *globalObj;
 
-    QHBoxLayout *mainLayout;
+    QVBoxLayout *mainLayout;
+    QHBoxLayout *topLayout;
     QVBoxLayout *leftLayout;
     QVBoxLayout *rightLayout;
     QHBoxLayout *rightLowerLayout;
@@ -95,6 +99,8 @@ private:
     AvatarButton *targetAvatarButton;
     bool haveTargetAvatar;
 
+    FilterMatchesWidget *filterMatchesWidget;
+
     bool itemIsNew;
     int itemHighlightType;
     QString createdAtTimestamp;
