@@ -25,6 +25,7 @@ FDNotifications::FDNotifications(QObject* parent) : QObject(parent)
 {
     qDebug() << "Creating FreeDesktop Notifier";
     this->notificationsAvailable = false; // Init as false, detect later
+    this->notificationDuration = 4000; // Milliseconds
 
 #ifdef QT_DBUS_LIB
     this->bus = new QDBusConnection(QDBusConnection::sessionBus());
@@ -72,12 +73,13 @@ bool FDNotifications::areNotificationsAvailable()
     return notificationsAvailable;
 }
 
-void FDNotifications::setNotificationOptions(int style,
+void FDNotifications::setNotificationOptions(int style, int duration,
                                              bool notifyNewTL, bool notifyHLTL,
                                              bool notifyNewMW, bool notifyHLMW,
                                              bool notifyErr)
 {
     this->notificationType = style;
+    this->notificationDuration = duration * 1000; // To ms
 
     this->notifyNewTimeline  = notifyNewTL;
     this->notifyHLTimeline   = notifyHLTL;
@@ -86,8 +88,8 @@ void FDNotifications::setNotificationOptions(int style,
     this->notifyErrors       = notifyErr;
 
     qDebug() << "Notification type set to"
-             << this->notificationType
-             << "-- FD.o/Qt/none";
+             << this->notificationType << "-- FD.o/Qt/none; Duration:"
+             << this->notificationDuration;
     qDebug() << this->notifyNewTimeline << this->notifyHLTimeline
              << this->notifyNewMeanwhile << this->notifyHLMeanwhile
              << this->notifyErrors;
@@ -158,7 +160,9 @@ void FDNotifications::showMessage(QString message)
         message.remove("</u>");
         message.replace("<br>", "\n");
         // FIXME: remove also <a href=...>
-        emit showFallbackNotification(notificationTitle, message);
+        emit showFallbackNotification(notificationTitle,
+                                      message,
+                                      this->notificationDuration);
 
         return;
     }
@@ -168,7 +172,8 @@ void FDNotifications::showMessage(QString message)
 #ifdef QT_DBUS_LIB
     message.replace("\n", "<br>"); // use HTML newlines
     // HTML newlines break notifications in Xfce; \n works, but is not actually
-    // shown as newline in Plasma 4's notifications
+    // shown as newline in Plasma 4's notifications.
+    // However, \n works fine in Plasma 5's notifications.
 
     QDBusMessage dBusMessage = QDBusMessage::createMethodCall(
                                  "org.freedesktop.Notifications",
@@ -195,9 +200,9 @@ void FDNotifications::showMessage(QString message)
     }
     arguments << notificationTitle;
     arguments << message;
-    arguments << QStringList();        // actions
-    arguments << QVariantMap();        // hints
-    arguments << 4000;                 // timeout, in milliseconds
+    arguments << QStringList();              // actions
+    arguments << QVariantMap();              // hints
+    arguments << this->notificationDuration; // timeout, in milliseconds
 
     dBusMessage.setArguments(arguments);
 
