@@ -42,7 +42,7 @@ public:
     ~FDNotifications();
 
     bool areNotificationsAvailable();
-    void setNotificationOptions(int style,
+    void setNotificationOptions(int style, int duration,
                                 bool notifyNewTL,
                                 bool notifyHLTL,
                                 bool notifyNewMW,
@@ -66,7 +66,7 @@ public:
 
 
 signals:
-    void showFallbackNotification(QString title, QString message);
+    void showFallbackNotification(QString title, QString message, int duration);
 
 
 public slots:
@@ -81,6 +81,8 @@ private:
     bool notificationsAvailable;
 
     int notificationType;
+    int notificationDuration;
+
     bool notifyNewTimeline;
     bool notifyHLTimeline;
     bool notifyNewMeanwhile;
