@@ -52,15 +52,13 @@ signals:
 public slots:
     void setToFirstPage();
     void setToLastPage();
+    void decreasePage();
+    void increasePage();
     void goToPage();
 
     void onPageNumberEntered();
+    void onPageNumberChanged(int selectedPage);
 
-    void toggleGoButton(int selectedPage);
-
-
-protected:
-    virtual void hideEvent(QHideEvent *event);
 
 
 private:
@@ -76,9 +74,9 @@ private:
     QPushButton *firstButton;
     QPushButton *lastButton;
 
-    QLabel *newerLabel;
+    QPushButton *newerButton;
     QSlider *pageNumberSlider;
-    QLabel *olderLabel;
+    QPushButton *olderButton;
 
     QPushButton *goButton;
     QPushButton *closeButton;
