@@ -41,6 +41,9 @@ PeopleWidget::PeopleWidget(QString buttonText,
 
     this->searchLineEdit = new QLineEdit(this);
     searchLineEdit->setPlaceholderText(tr("Enter a name here to search for it"));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    searchLineEdit->setClearButtonEnabled(true);
+#endif
     searchLabel->setBuddy(searchLineEdit);
     connect(searchLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(filterList(QString)));
