@@ -142,15 +142,20 @@ Post::Post(ASActivity *activity,
                               + ": "
                               + activity->object()->getTranslatedType(postType)
                               + " - Dianara";
+        this->setWindowIcon(QIcon::fromTheme("mail-message",
+                                             QIcon(":/images/button-edit.png")));
         this->setWindowTitle(windowTitle);
-        this->setWindowFlags(Qt::Dialog);
-        this->setWindowModality(Qt::WindowModal);
+        this->setWindowFlags(Qt::Window);
+        this->setWindowModality(Qt::NonModal);
 
         // Restore size
         this->setMinimumSize(420, 360);
         QSettings settings;
         this->resize(settings.value("Post/postSize",
                                     QSize(600, 440)).toSize());
+
+        connect(globalObj, SIGNAL(programShuttingDown()),
+                this, SLOT(close()));
     }
 
     postIsUnread = false;
@@ -338,6 +343,10 @@ Post::Post(ASActivity *activity,
         // -----
         postAuthorAvatarButton->addSeparatorToMenu();
 
+        /*
+         * 1.3.5: This will probably not be needed anymore for any environment
+         *        since Posts are now windows, not dialogs, but still...
+         */
         this->closeAction = new QAction(QIcon::fromTheme("window-close",
                                                          QIcon(":/images/button-close.png")),
                                         tr("&Close"),
@@ -506,7 +515,8 @@ Post::Post(ASActivity *activity,
                                                                 QIcon(":/images/button-parent.png")),
                                                tr("Parent",
                                                   "As in 'Open the parent post'. "
-                                                  "Try to use the shortest word!"));
+                                                  "Try to use the shortest word!"),
+                                               this);
         //openParentPostButton->setFlat(true);
         openParentPostButton->setFont(buttonsFont);
         openParentPostButton->setSizePolicy(QSizePolicy::Ignored,
@@ -519,23 +529,6 @@ Post::Post(ASActivity *activity,
         leftColumnLayout->addWidget(openParentPostButton);
     }
 
-    // If showing standalone, add a Close button; needed in some environments
-    // Button disabled for now; added option to avatar menu
-#if 0
-    if (standalone)
-    {
-        this->closeButton = new QPushButton(QIcon::fromTheme("window-close",
-                                                             QIcon(":/images/button-close.png")),
-                                            tr("&Close"));
-        closeButton->setFont(buttonsFont);
-        closeButton->setSizePolicy(QSizePolicy::Ignored,
-                                   QSizePolicy::Maximum);
-        connect(closeButton, SIGNAL(clicked()),
-                this, SLOT(close()));
-
-        leftColumnLayout->addWidget(closeButton);
-    }
-#endif
 
     leftColumnFrame->setLayout(leftColumnLayout);
 
@@ -575,12 +568,11 @@ Post::Post(ASActivity *activity,
 
     ///////////////////////////////////// Post text
     postText = new QTextBrowser(this);
-    postText->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postText->setSizePolicy(QSizePolicy::MinimumExpanding,
                             QSizePolicy::MinimumExpanding);
     postText->setMinimumSize(10, 10);
     postText->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-    postText->setOpenLinks(false); // don't open links, manage in openClickedURL()
+    postText->setOpenLinks(false); // don't open links, manage in openClickedUrl()
     postText->setReadOnly(true); // it's default with QTextBrowser, but still...
 
     QFont postContentsFont;
@@ -593,7 +585,7 @@ Post::Post(ASActivity *activity,
     //postText->setTextInteractionFlags(Qt::TextBrowserInteraction
     //                                  | Qt::TextSelectableByKeyboard);
     connect(postText, SIGNAL(anchorClicked(QUrl)),
-            this, SLOT(openClickedURL(QUrl)));
+            this, SLOT(openClickedUrl(QUrl)));
     connect(postText, SIGNAL(highlighted(QString)),
             this, SLOT(showHighlightedUrl(QString)));
     rightColumnLayout->addWidget(postText, 1); // No alignment; makes size wrong when standalone
@@ -602,7 +594,6 @@ Post::Post(ASActivity *activity,
     // Buttons
     // Add like, comment, share and, if post is ours, edit and delete buttons
     buttonsLayout = new QHBoxLayout();
-    buttonsLayout->setAlignment(Qt::AlignHCenter | Qt::AlignTop);
     buttonsLayout->setContentsMargins(0, 0, 0, 0);
     buttonsLayout->setMargin(0);
     buttonsLayout->setSpacing(0);
@@ -809,19 +800,25 @@ Post::Post(ASActivity *activity,
     }
 
 
-    this->resizesCount = 0;
-    // Post resizing takes place in resizeEvent()
-    // which will also call setPostContents()
-
-
     // FIXME: button creation should be moved here
     rightColumnLayout->addLayout(buttonsLayout, 0);
 
 
+    // Show which filtering rules caused this post to be highlighted
+    QVariantMap filterMatches = activity->getFilterMatches();
+    if (filterMatches.value("filterAction").toInt() == FilterChecker::Highlight)
+    {
+        this->filterMatchesWidget = new FilterMatchesWidget(filterMatches, this);
+        rightColumnLayout->addWidget(filterMatchesWidget);
+        // FIXME -- TODO: make this widget optional + way to hide it later
+    }
+
+
     ///////////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////// Comments block
     this->commenter = new CommenterBlock(this->pController,
                                          this->globalObj,
+                                         this->postId,
                                          this->postAuthorId,
                                          this->standalone,
                                          this);
@@ -831,6 +828,7 @@ Post::Post(ASActivity *activity,
             this, SLOT(updateComment(QString,QString)));
     connect(commenter, SIGNAL(allCommentsRequested()),
             this, SLOT(getAllComments()));
+
     rightColumnLayout->addWidget(commenter, 0);
     rightColumnLayout->addStretch(0); // Push other stuff to the top if there's extra space
 
@@ -843,7 +841,7 @@ Post::Post(ASActivity *activity,
 
         this->updateBestCommentsUrl();
         // If we still don't have a valid URL from our host, proxyURL or not..
-        if (!pController->urlIsInOurHost(this->postCommentsUrl))
+        if (!this->canGetAllComments())
         {
             this->commenter->disableShowAllLink();
         }
@@ -890,6 +888,11 @@ Post::Post(ASActivity *activity,
     this->setFuzzyTimestamps();
 
 
+    this->resizeTimer = new QTimer(this);
+    resizeTimer->setSingleShot(true);
+    connect(resizeTimer, SIGNAL(timeout()),
+            this, SLOT(delayedResize()));
+
 
     this->updateDataFromActivity(activity);
 
@@ -967,7 +970,7 @@ void Post::updateDataFromObject(ASObject *object)
     this->setFuzzyTimestamps();
 
 
-    // Save post title for openClickedURL(), editPost() etc
+    // Save post title for openClickedUrl(), editPost() etc
     this->postTitle = object->getTitle();
     if (!this->postTitle.isEmpty())
     {
@@ -1085,7 +1088,7 @@ void Post::setCommentDeletedFromObject(ASObject *object)
  */
 void Post::setPostContents()
 {
-    //qDebug() << "Post::setPostContents()" << this->postID;
+    //qDebug() << "Post::setPostContents()" << this->postId;
     QString postMediaHtml;
 
     // Embedded image
@@ -1246,11 +1249,6 @@ void Post::setPostHeight()
 }
 
 
-void Post::resetResizesCount()
-{
-    this->resizesCount = 0;
-}
-
 
 /*
  * Download post image, and img-tag-based images parsed from the contents
@@ -1397,7 +1395,7 @@ void Post::setLikesLabel(int likesCount)
  * Return the comments URL for this post
  *
  */
-QString Post::commentsURL()
+QString Post::commentsUrl()
 {
     return this->postCommentsUrl;
 }
@@ -1479,13 +1477,12 @@ void Post::updateBestCommentsUrl()
 
 
 
-
 /*
  * Return the shares URL for this post,
  * list of people who reshared it
  *
  */
-QString Post::sharesURL()
+QString Post::sharesUrl()
 {
     return this->postSharesUrl;
 }
@@ -1804,7 +1801,10 @@ void Post::commentOnPost()
     this->commenter->setFullMode(initialText);
 
     // Show "Check for comments" link, if it wasn't present, in some form, already
-    this->commenter->updateShowAllLink();
+    if (this->canGetAllComments()) // As long as we can actually get them
+    {
+        this->commenter->updateShowAllLink();
+    }
 
 
     emit commentingOnPost(this->commenter);
@@ -1827,10 +1827,21 @@ void Post::sendComment(QString commentText)
                                   this->postId, this->postType);
 }
 
+
 void Post::updateComment(QString commentId, QString commentText)
 {
     this->pController->updateComment(commentId,
-                                     MiscHelpers::cleanupHtml(commentText));
+                                     MiscHelpers::cleanupHtml(commentText),
+                                     this->postId);
+}
+
+
+void Post::requestCommenterComments()
+{
+    if (this->canGetAllComments())
+    {
+        this->commenter->requestAllComments();
+    }
 }
 
 
@@ -1852,12 +1863,12 @@ void Post::getAllComments()
         if (postFoundOk)
         {
             qDebug() << "Found the post; Updating comments Url...";
-            this->postCommentsUrl = alternatePost->commentsURL();
+            this->postCommentsUrl = alternatePost->commentsUrl();
         }
         */
 
 
-    this->pController->getPostComments(this->postCommentsUrl);
+    this->pController->getPostComments(this->postCommentsUrl, this->postId);
 }
 
 
@@ -1869,13 +1880,19 @@ void Post::getAllComments()
 void Post::setAllComments(QVariantList commentsList, QString originatingPostUrl)
 {
     QString originatingPostCleanUrl = originatingPostUrl.split("?").first();
-    if (this->commentsURL() == originatingPostCleanUrl)
+    if (this->commentsUrl() == originatingPostCleanUrl)
     {
         this->setComments(commentsList);
     }
 }
 
 
+bool Post::canGetAllComments()
+{
+    return pController->urlIsInOurHost(this->postCommentsUrl);
+}
+
+
 /*
  * Share a post.
  *
@@ -1888,10 +1905,21 @@ void Post::sharePost()
     // Clicking 'Share' doesn't generate a mousePressEvent, so mark as read here
     this->setPostAsRead();
 
+    QString shareConfirmString;
+    if (!this->postIsOwn)
+    {
+        shareConfirmString = tr("Do you want to share %1's post?")
+                             .arg(this->postAuthorName);
+    }
+    else
+    {
+        shareConfirmString = tr("Are you sure you want to share "
+                                "your own post?");
+    }
+
 
     int confirmation = QMessageBox::question(this, tr("Share post?"),
-                                             tr("Do you want to share %1's post?")
-                                              .arg(this->postAuthorName)
+                                             shareConfirmString
                                              + "\n\n\n",
                                              tr("&Yes, share it"), tr("&No"),
                                              "", 1, 1);
@@ -1983,7 +2011,7 @@ void Post::joinGroup()
 
 
 
-void Post::openClickedURL(QUrl url)
+void Post::openClickedUrl(QUrl url)
 {
     qDebug() << "Anchor URL clicked:" << url.toString();
 
@@ -2000,7 +2028,7 @@ void Post::openClickedURL(QUrl url)
                                               this->postTitle,
                                               suggestedFilename,
                                               this->postImageIsAnimated,
-                                              this);
+                                              nullptr); // Independent window
         connect(pController, SIGNAL(imageStored(QString)),
                 viewer, SLOT(reloadImage(QString)));
         connect(pController, SIGNAL(imageFailed(QString)),
@@ -2068,7 +2096,8 @@ void Post::copyPostUrlToClipboard()
 
 void Post::openParentPost()
 {
-    qDebug() << "Opening parent post...";
+    qDebug() << "Opening parent post..."
+             << this->postParentMap.value("id").toString();
 
     // Create a fake activity for the parent post
     QVariantMap fakeActivityMap;
@@ -2084,13 +2113,11 @@ void Post::openParentPost()
                                 true,  // Post is standalone
                                 pController,
                                 globalObj,
-                                this->parentWidget()); // Pass parent widget (Timeline or
-                                                       // another Post) instead of
-                                                       // 'this', so it won't be killed by reloads
+                                nullptr); // Independent window
     parentPost->show();
     connect(pController, SIGNAL(commentsReceived(QVariantList,QString)),
             parentPost, SLOT(setAllComments(QVariantList,QString)));
-    parentPost->getAllComments();
+    parentPost->requestCommenterComments();
 }
 
 
@@ -2131,6 +2158,12 @@ void Post::triggerResize()
 }
 
 
+void Post::delayedResize()
+{
+    this->onResizeOrShow();
+}
+
+
 
 /*
  * Redraw post contents after receiving downloaded images
@@ -2175,23 +2208,8 @@ void Post::onImageFailed(QString imageUrl)
 
 void Post::resizeEvent(QResizeEvent *event)
 {
-    //qDebug() << "Post::resizeEvent()" << event->size();
-    if (this->resizesCount > 10) // Don't resize more than 10 times in a row
-    {
-        qDebug() << "Post::resizeEvent(); Too many resizes, too fast; ignoring!";
-        event->ignore();
-
-        return;
-    }
-
-    this->onResizeOrShow();
-
-
-    // Standalone mode doesn't need this kind of protection, and is not re-set by Timeline()
-    if (!standalone)
-    {
-        ++this->resizesCount;
-    }
+    this->resizeTimer->stop();
+    this->resizeTimer->start(200); // Schedule content resize
 
     event->accept();
 }
@@ -2254,17 +2272,24 @@ void Post::closeEvent(QCloseEvent *event)
         }
     }
 
-    if (this->commenter->isFullMode())
+    if (this->commenter->isFullMode()
+     && !this->globalObj->isProgramShuttingDown())
     {
-        // Ask composer to cancel post, which asks the user, unless empty
+        // Ask composer to cancel post, which asks the user (unless empty)
         this->commenter->getComposer()->cancelPost();
+
+        /*
+         * TODO / FIXME: avoid asking for confirmation only when the program
+         *               is shutting down due to environment's request
+         */
     }
 
     event->ignore(); // Event will be ignored anyway
 
 
     // Check again; if it's still full, it means user cancelled
-    if (!this->commenter->isFullMode()) // If not, accepted, so kill the post
+    if (!this->commenter->isFullMode() // If not, user accepted, so kill the post
+      || this->globalObj->isProgramShuttingDown()) // Kill it either way if shutting down
     {
         this->hide();
         this->deleteLater();
