@@ -51,6 +51,7 @@
 #include "avatarbutton.h"
 #include "downloadwidget.h"
 #include "hclabel.h"
+#include "filtermatcheswidget.h"
 
 
 class Post : public QFrame
@@ -75,7 +76,6 @@ public:
     void setPostContents();
     void onResizeOrShow();
     void setPostHeight();
-    void resetResizesCount();
     void getPendingImages();
 
     QString likesUrl();
@@ -86,14 +86,14 @@ public:
     void setLikesLabel(int likesCount);
 
 
-    QString commentsURL();
+    QString commentsUrl();
     void setComments(QVariantList commentsList);
     void appendComment(ASObject *comment);
     void setCommentsLabel(int commentsCount);
     void updateBestCommentsUrl();
 
 
-    QString sharesURL();
+    QString sharesUrl();
     void setShares(QVariantList sharesList, int sharesCount=-1);
     void setSharesLabel(int resharesCount);
 
@@ -136,9 +136,11 @@ public slots:
     void sendComment(QString commentText);
     void updateComment(QString commentId, QString commentText);
 
+    void requestCommenterComments();
     void getAllComments();
     void setAllComments(QVariantList commentsList,
                         QString originatingPostUrl);
+    bool canGetAllComments();
 
     void sharePost();
     void unsharePost();
@@ -149,7 +151,7 @@ public slots:
 
     void joinGroup();
 
-    void openClickedURL(QUrl url);
+    void openClickedUrl(QUrl url);
     void showHighlightedUrl(QString url);
 
 
@@ -159,6 +161,7 @@ public slots:
     void normalizeTextFormat();
 
     void triggerResize();
+    void delayedResize();
 
     void redrawImages(QString imageUrl);
     void onImageFailed(QString imageUrl);
@@ -240,6 +243,8 @@ private:
 
     DownloadWidget *downloadWidget;
 
+    FilterMatchesWidget *filterMatchesWidget;
+
     QString postTitle;
     QString postSmallImageUrl;
     QString postFullImageUrl;
@@ -260,7 +265,6 @@ private:
     QString postGeneratorString;
 
     int postWidth;
-    int resizesCount;
 
     QString postLikesUrl;
     int postLikesCount;
@@ -276,6 +280,8 @@ private:
     QString seeFullImageString;
     QString downloadAttachmentString;
 
+    QTimer *resizeTimer;
+
     PumpController *pController;
     GlobalObject *globalObj;
     CommenterBlock *commenter;
