@@ -34,33 +34,34 @@ ProxyDialog::ProxyDialog(int proxyType,
     this->setWindowModality(Qt::WindowModal);
     this->setMinimumSize(380, 320);
 
-    proxyTypeComboBox = new QComboBox();
+    proxyTypeComboBox = new QComboBox(this);
     proxyTypeComboBox->addItem(tr("Do not use a proxy"));
     proxyTypeComboBox->addItem("SOCKS 5");
     proxyTypeComboBox->addItem("HTTP");
     proxyTypeComboBox->setCurrentIndex(proxyType);
 
-    hostnameLineEdit = new QLineEdit(hostname);
+    hostnameLineEdit = new QLineEdit(hostname, this);
     hostnameLineEdit->setPlaceholderText("example.org");
 
-    portLineEdit = new QLineEdit(port);
+    portLineEdit = new QLineEdit(port, this);
     portLineEdit->setPlaceholderText("1080, 8080..."); // defaults for socks5 and http
 
-    authCheckBox = new QCheckBox();
+    authCheckBox = new QCheckBox(this);
     authCheckBox->setChecked(useAuth);
     connect(authCheckBox, SIGNAL(toggled(bool)),
             this, SLOT(toggleAuth(bool)));
 
-    userLineEdit = new QLineEdit(user);
+    userLineEdit = new QLineEdit(user, this);
     userLineEdit->setPlaceholderText(tr("Your proxy username"));
 
-    passwordLineEdit = new QLineEdit(password);
+    passwordLineEdit = new QLineEdit(password, this);
     passwordLineEdit->setEchoMode(QLineEdit::Password);
 
     passwordNoteLabel = new QLabel(tr("Note: Password is not stored in a "
                                       "secure manner. If you wish, you can "
                                       "leave the field empty, and you'll be "
-                                      "prompted for the password on startup."));
+                                      "prompted for the password on startup."),
+                                   this);
     passwordNoteLabel->setWordWrap(true);
     QFont noteFont;
     noteFont.setPointSize(noteFont.pointSize() - 1);
@@ -71,13 +72,15 @@ ProxyDialog::ProxyDialog(int proxyType,
     // Bottom
     saveButton = new QPushButton(QIcon::fromTheme("document-save",
                                                   QIcon(":/images/button-save.png")),
-                                 tr("&Save"));
+                                 tr("&Save"),
+                                 this);
     connect(saveButton, SIGNAL(clicked()),
             this, SLOT(saveSettings()));
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
-                                   tr("&Cancel"));
+                                   tr("&Cancel"),
+                                   this);
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(hide()));
 
