@@ -31,7 +31,7 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QNetworkAccessManager>
-#include <QSslError> // TMP
+#include <QSslError>
 #include <QNetworkProxy>
 #include <QTimer>
 #include <QFile>
@@ -192,7 +192,7 @@ public:
     void leaveGroup(QString id);
 
     void getPostLikes(QString postLikesUrl);
-    void getPostComments(QString postCommentsUrl);
+    void getPostComments(QString postCommentsUrl, QString postId);
     void getPostShares(QString postSharesUrl);
 
     void getFeed(requestTypes feedType, int itemCount,
@@ -280,6 +280,7 @@ signals:
 
     void likesReceived(QVariantList likesList, QString originatingPostURL);
     void commentsReceived(QVariantList commentsList, QString originatingPostURL);
+    void commentsNotReceived(QString requestedUrl);
 
     void minorFeedMainReceived(QVariantList activitiesList,
                                QString previousLink, QString nextLink,
@@ -303,8 +304,8 @@ signals:
     void postPublished();
     void postPublishingFailed();
     void likeSet();
-    void commentPosted();
-    void commentPostingFailed();
+    void commentPosted(QString parentPostId);
+    void commentPostingFailed(QString parentPostId);
 
     void userDidSomething();
 
@@ -343,12 +344,12 @@ public slots:
 
     void likePost(QString postId, QString postType, QString authorId, bool like);
 
-    void addComment(QString comment, QString postID, QString postType);
-    void updateComment(QString id, QString content);
+    void addComment(QString comment, QString postId, QString postType);
+    void updateComment(QString id, QString content, QString inReplyToId);
 
-    void sharePost(QString postID, QString postType);
+    void sharePost(QString postId, QString postType);
     void unsharePost(QString postId, QString postType);
-    void deletePost(QString postID, QString postType);
+    void deletePost(QString postId, QString postType);
 
     void followContact(QString address);
     void followVerifiedContact(QString address);
