@@ -34,7 +34,7 @@ SiteUsersList::SiteUsersList(PumpController *pumpController,
                        + tr("More resources to find users:")
                        + "<ul>"
                          "<li>"
-                         "<a href=\"https://github.com/e14n/pump.io/wiki/Users-by-language\">"
+                         "<a href=\"https://github.com/pump-io/pump.io/wiki/Users-by-language\">"
                        + tr("Wiki page 'Users by language'")
                        + "</a>."
                          "</li>"
