@@ -58,7 +58,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     demoObjectData.insert("id",             "demo-post-id");
 
     // Show date/time when latest stable version was released
-    demoObjectData.insert("published",      "2016-10-09T19:00:00Z");
+    demoObjectData.insert("published",      "2016-12-17T21:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -347,12 +347,16 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     previousPageAction->setShortcut(QKeySequence("Ctrl+Left"));
     connect(previousPageAction, SIGNAL(triggered()),
             previousPageButton, SLOT(click()));
+    previousPageButton->setToolTip(previousPageAction->shortcut()
+                                   .toString(QKeySequence::NativeText));
     this->addAction(previousPageAction);
 
     nextPageAction = new QAction(this);
     nextPageAction->setShortcut(QKeySequence("Ctrl+Right"));
     connect(nextPageAction, SIGNAL(triggered()),
             nextPageButton, SLOT(click()));
+    nextPageButton->setToolTip(nextPageAction->shortcut() // FIXME: maybe add a clearer message
+                               .toString(QKeySequence::NativeText));
     this->addAction(nextPageAction);
 
     // It's safer to use these QActions than setting shortcuts to buttons
