@@ -30,9 +30,11 @@ UserPosts::UserPosts(QString userId, QString userName,
 {
     this->pController = pumpController;
     this->globalObj = globalObject;
+    connect(globalObj, SIGNAL(programShuttingDown()),
+            this, SLOT(close()));
 
-    this->setWindowFlags(Qt::Dialog);
-    this->setWindowModality(Qt::WindowModal);
+    this->setWindowFlags(Qt::Window);
+    this->setWindowModality(Qt::NonModal);
 
     this->timelineTitle = tr("Posts by %1").arg(userName);
     this->setWindowTitle(timelineTitle + " - Dianara");
